@@ -9,10 +9,10 @@
 ;; Maintainer:   Robert Weiner <rsw@gnu.org>
 ;; Maintainers:  Robert Weiner <rsw@gnu.org>, Mats Lidell <matsl@gnu.org>
 ;; Created:      06-Oct-92 at 11:52:51
-;; Last-Mod:     31-Dec-25 at 16:02:19 by Mats Lidell
+;; Last-Mod:     18-Jan-26 at 08:29:42 by Bob Weiner
 ;; Released:     10-Mar-24
-;; Package-Version: 20260120.958
-;; Package-Revision: b8344d5987c0
+;; Package-Version: 20260209.531
+;; Package-Revision: 05af28aa80c2
 ;; Keywords:     comm, convenience, files, frames, hypermedia, languages, mail, matching, mouse, multimedia, outlines, tools, wp
 ;; Package:      hyperbole
 ;; Package-Requires: ((emacs "28"))
@@ -181,6 +181,7 @@ Info documentation at \"(hyperbole)Top\".
 (require 'set (expand-file-name "set" hyperb:dir))
 (require 'hypb)
 (require 'hui-select)  ;; This requires 'hvar which defines the var:append function.
+(require 'hywiki)
 
 ;;; ************************************************************************
 ;;; Public Variables
@@ -501,7 +502,7 @@ frame, those functions by default still return the prior frame."
   ;; loaded parts of Org before his load path is finalized.  It loads
   ;; the newer version of Org, if any, assuming `load-path' is configured
   ;; correctly.
-  (hsys-org-fix-version)
+  ;; (hsys-org-fix-version)
   ;;
   ;; When vertico-mode is used, vertico-mouse-mode is needed for the
   ;; Action Key to properly select completions from the candidate
@@ -510,6 +511,9 @@ frame, those functions by default still return the prior frame."
   (when (fboundp #'vertico-mouse-mode)
     (add-hook 'vertico-mode-hook (lambda () (vertico-mouse-mode 1))))
   ;;
+  ;; Set HyWiki page auto-HyWikiWord highlighting and `yank-handled-properties'
+  (hywiki-mode :pages)
+  ;;
   ;; Hyperbole initialization is complete.
   (message "Initializing Hyperbole...done"))
   
